# Template for python package

TODO: replace project dependencies
Test

![banner](https://bmeyn.github.io/temp_python_pkg/docs/images/project-banner.png)

*****
TODO: replace project dependencie
[![HitCount](https://hits.dwyl.com/BMeyn/temp_python_package.svg?style=flat-square)](http://hits.dwyl.com/BMeyn/temp_python_package)
[![PyPI version](https://badge.fury.io/py/BMeyn.svg)](https://badge.fury.io/py)
[![Tests Status](https://bmeyn.github.io/temp_python_pkg/docs/badget/tests-badget.svg?dummy=8484744)](https://smarie.github.io/python-genbadge/reports/junit/report.html)
[![Coverage Status](https://bmeyn.github.io/temp_python_pkg/docs/badget/coverage-badget.svg?dummy=8484744)](https://github.com/BMeyn/temp_python_pkg)

## Features:
-
-
-

## Install:

```
pip install package_name
```

## Usage:

Todo: provide examples how to use your package

## Contribution:

Todo: describe how to contribute to the project

## required action secrets
- codecov_token
  - adds test code coverage annotations to PRs
- flake8_token #TODO: rename token
  - github token for read and write access 
  - required to update PRs with actions
- pypi_test_token
  - Api token for pypi test releases
  - required for python package test release
- pypi_token
  - api token for pypi release
  - required for python package release
